#!/usr/bin/python
#
# commit-wrangler.py - basic script to commit patches, primarily for
# Metacity, might be useful for others. In early stages of
# development.
#
# Copyright (C) 2008 Thomas Thurman
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import time
import commands
import sys
import os
import posixpath
import ConfigParser
import re

# FIXME: Needs tidying into separate functions.

# FIXME: Some of this is duplicated from release-wrangler.
# This should go in a common library when the dust has settled.

# FIXME: Some way of updating Bugzilla when we mention a bug,
# and including the revision number, would be really useful.

# FIXME: This should co-operate with patch-wrangler in that
# p-w should find out the name of a patch's submitter from bugzilla
# and store it in a dotfile, and then we can use it here.
# Also, it should find out and store the bug number, so we can
# write it as "(Bug #nnn)", which will make the previous paragraph's
# idea even more useful.

def get_up_to_date():
  "First step is always to get up to date."
  os.system("svn up")

def report_error(message):
  print message
  sys.exit(255)

def favourite_editor():
  e = os.environ
  if e.has_key('VISUAL'): return e['VISUAL']
  if e.has_key('EDITOR'): return e['EDITOR']
  if os.access('/usr/bin/nano', os.F_OK):
    return '/usr/bin/nano'
  report_error("I can't find an editor for you!")

def wordwrap(str, prefix=''):
  "Really simple wordwrap"

  # Ugly hack:
  # We know that all open brackets are preceded by spaces.
  # We don't want to split on these spaces. Therefore:
  str = str.replace(' (','(')

  result = ['']
  for word in str.split():

    if result[-1]=='':
      candidate = prefix + word
    else:
      candidate = '%s %s' % (result[-1], word)

    if len(candidate)>80:
      result.append(prefix+word)
    else:
      result[-1] = candidate

  return '\n'.join(result).replace('(',' (')

#####################

change_filename = 'ChangeLog'

get_up_to_date()

cp = ConfigParser.ConfigParser()
cp.read(os.environ['HOME']+'/.config/metacity/tools.ini')

os.environ['CHANGE_LOG_NAME'] = cp.get('commit-wrangler', 'name')
os.environ['CHANGE_LOG_EMAIL_ADDRESS'] = cp.get('commit-wrangler', 'address')

print commands.getoutput('moap cl prep')

time_before = os.stat(change_filename)[8]
os.system(favourite_editor()+' +6 %s ' % (change_filename))

if os.stat(change_filename)[8] == time_before:
    print 'No change; aborting:'
    print commands.getoutput('svn revert '+change_filename)
    sys.exit(0)

# Update the changelog

checkin = commands.getoutput("moap cl ci")

print re.sub(".*Committed revision (\\d+).*", 'http://svn.gnome.org/viewvc/metacity?rev=\\1&view=rev', checkin)




#!/usr/bin/env python3

# Copyright (C) 2016 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.

import os
import sys

if len(sys.argv) != 2:
  print("Usage: %s [output file]"%sys.argv[0])
  exit(1)

common_resolutions = [
    # 4:3
    (800, 600),
    (1024, 768),
    (1152, 864),
    (1280, 960),
    (1400, 1050),
    (1440, 1080),
    (1600, 1200),
    (1920, 1440),
    (2048, 1536),
    # 16:10
    (1280, 800),
    (1440, 900),
    (1680, 1050),
    (1920, 1200),
    (2560, 1600),
    # 16:9
    (1280, 720),
    (1366, 768),
    (1600, 900),
    (1920, 1080),
    (2048, 1152),
    (2560, 1440),
    (2880, 1620),
    (3200, 1800),
    (3840, 2160),
    (4096, 2304),
    (5120, 2880),
]

output_lines = [
    "/* Generated by gen-default-modes.py */\n",
    "static const drmModeModeInfo meta_default_landscape_drm_mode_infos[] = {",
]

def sync_flags(hsync, vsync):
    flags = "DRM_MODE_FLAG_"
    flags += "NHSYNC" if hsync[0] == '-' else "PHSYNC"
    flags += " | DRM_MODE_FLAG_"
    flags += "NVSYNC" if vsync[0] == '-' else "PVSYNC"
    return flags

def drm_mode_info_from_modeline(line):
    sline = line.split()
    return "{ %d, %d, %d, %d, %d, 0, %d, %d, %d, %d, 0, 0, %s, DRM_MODE_TYPE_DEFAULT, %s }," % \
        (int(float(sline[2]) * 1000),
         int(sline[3]),
         int(sline[4]),
         int(sline[5]),
         int(sline[6]),
         int(sline[7]),
         int(sline[8]),
         int(sline[9]),
         int(sline[10]),
         sync_flags(sline[11], sline[12]),
         sline[1])

def portrait_drm_mode_info_from_modeline(line):
    sline = line.split()
    return "{ %d, %d, %d, %d, %d, 0, %d, %d, %d, %d, 0, 0, %s, DRM_MODE_TYPE_DEFAULT, \"%dx%d_60.00\" }," % \
        (int(float(sline[2]) * 1000),
         int(sline[7]),
         int(sline[8]),
         int(sline[9]),
         int(sline[10]),
         int(sline[3]),
         int(sline[4]),
         int(sline[5]),
         int(sline[6]),
         sync_flags(sline[12], sline[11]),
         int(sline[7]), int(sline[3]))

for resolution in common_resolutions:
    cvt = os.popen("%s %s %s" % ('cvt', resolution[0], resolution[1]))
    cvt.readline() # discard comment line
    line = cvt.readline()
    output_lines.append(drm_mode_info_from_modeline(line))
    cvt.close()
output_lines.append("};")

output_lines.append("")
output_lines.append("static const drmModeModeInfo meta_default_portrait_drm_mode_infos[] = {")
for resolution in common_resolutions:
    cvt = os.popen("%s %s %s" % ('cvt', resolution[0], resolution[1]))
    cvt.readline() # discard comment line
    line = cvt.readline()
    output_lines.append(portrait_drm_mode_info_from_modeline(line))
    cvt.close()
output_lines.append("};")

try:
  output_file = open(sys.argv[1], 'w')

  for line in output_lines:
      output_file.write(line + "\n")
  output_file.flush()
  output_file.close()
except:
  print("Failed to generate modelines:", sys.exc_info()[0])
  exit(1)
